@@ -60,6 +60,7 @@ def _add_ds_to_resp(ds: NumpyDataset, resp: falcon.Response) -> None:
     (X, y) = ds.get()
     arrays = dict(X=X, y=y)
     resp.data = utils.named_ndarrays_to_bytes(arrays)
+    resp.content_type = "application/octet-stream"
 
 
 class DynamicNumpyDataResource:
@@ -179,7 +180,7 @@ def supervised_learning_MIA_challenge_server_factory(
     * [GET] `/data/anonymizer/validation`
     * [GET] `/data/deanonymizer/members`
     * [GET] `/data/deanonymizer/non-members`
-    * [GET] `/data/attack-success-evaluation/`
+    * [GET] `/data/attack-success-evaluation`
     * [POST] `/utility/anonymizer`
     * [POST] `/utility/deanonymizer`
 
@@ -219,7 +220,7 @@ def supervised_learning_MIA_challenge_server_factory(
         StaticNumpyDataResource(challenge_obj.non_members),
     )
     app.add_route(
-        r"/data/attack-success-evaluation/",
+        r"/data/attack-success-evaluation",
         DynamicNumpyDataResource(
             lambda req: challenge_obj.MIA_evaluation_data(
                 anonymizer=req.get_param("anonymizer", required=True),
