@@ -105,7 +105,7 @@ def test_get_deanon_non_members(client):
 def test_get_MIA_eval_data(client):
     assert _route_represents_dataset(
         client,
-        "/data/attack-success-evaluation/",
+        "/data/attack-success-evaluation",
         query_params=dict(
             deanonymizer="example-deanonymizer",
             anonymizer="example-anonymizer",
